## $Id: export.py 15515 2019-07-24 20:41:06Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Exporters for applicant-related stuff.
"""
import grok
from waeup.kofa.applicants.interfaces import (
    IApplicantBaseData, IApplicantOnlinePayment)
from waeup.kofa.utils.helpers import iface_names
from waeup.kofa.applicants.export import ApplicantPaymentExporter
from kofacustom.nigeria.applicants.export import NigeriaApplicantExporter
from kofacustom.nigeria.applicants.interfaces import (
    INigeriaUGApplicant, INigeriaPGApplicant)
from kofacustom.dspg.applicants.interfaces import (
    ICustomUGApplicant, ICustomPGApplicant, ICustomSpecialApplicant)

class CustomApplicantExporter(NigeriaApplicantExporter):
    """Exporter for Custom Applicants.
    """

    fields = tuple(sorted(set(
        iface_names(ICustomUGApplicant) +
        iface_names(ICustomPGApplicant) +
        iface_names(ICustomSpecialApplicant) +
        iface_names(INigeriaUGApplicant) +
        iface_names(INigeriaPGApplicant) +
        iface_names(IApplicantBaseData)
        ))) + (
        'password', 'state', 'history', 'container_code', 'application_number',
        'display_fullname', 'application_date')

class CustomApplicantPaymentExporter(ApplicantPaymentExporter):
    """
    """
    fields = tuple(sorted(iface_names(
        IApplicantOnlinePayment,
        exclude_attribs=False,
        omit=['display_item']))) + (
              'applicant_id',
              'reg_number',
              'display_fullname',
              'course1',
              'course2')

    def mangle_value(self, value, name, context=None):
        """
        """
        if name in ('applicant_id', 'reg_number',
            'display_fullname') and context is not None:
            applicant = context.__parent__
            value = getattr(applicant, name, None)
        if name in ('course1', 'course2') and context is not None:
            applicant = context.__parent__
            value = getattr(getattr(applicant, name, None), code, None)
        return super(
            CustomApplicantPaymentExporter, self).mangle_value(
            value, name, context=context)
